fedex.printers

Package fedex :: Package printers |
[hide private]
[frames] | no frames]

# Source Code for Package fedex.printers

     1  """
     2  Optional classes used for the convenient printing of FedEx labels from
     3  L{FedexProcessShipmentRequest} objects. Each printer class is more or less
     4  the same, following the pattern seen below (unless otherwise documented).::
     5      from fedex.printers.unix import DirectDevicePrinter
     6      # Where shipment is an existing L{FedexProcessShipmentRequest} object.
     7      shipment.send_request()
     8      device = DirectDevicePrinter(shipment)
     9      device.print_label()
    10  """
    11